@@ -610,13 +610,11 @@ L<Vote::Count::Start|https://metacpan.org/pod/Vote::Count::Start>
 
 =head3 Documentation
 
-Additional Documentation Files
-
 =over
 
 =item *
 
-L<Vote::Count::HandCount|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Count/Method/HandCount.pod>
+L<Vote::Count::HandCount|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Count/Method/Hand_Count.pod>
 
 
 =item *
