@@ -54,6 +54,10 @@ sub _ResolveTie ( $self, $active, $tiebreaker, @choices ) {
   return @low;
 }
 
+sub _irvrange ( $self, $active, $tiebreaker = undef ) {
+  ...;
+}
+
 sub RunIRV ( $self, $active = undef, $tiebreaker = undef ) {
   # external $active should not be changed.
   if ( defined $active ) { $active = dclone $active }
@@ -67,8 +71,8 @@ sub RunIRV ( $self, $active = undef, $tiebreaker = undef ) {
       $tiebreaker = 'all';
     }
   }
-  # deref self->Active from any other references IRV alters it.
-  # else { $self->{'Active'} = { $active->%* } }
+  if( $self->BallotSetType() eq 'range') {
+    return $self->_irvrange ( $active, $tiebreaker) }
   my $roundctr = 0;
   my $maxround = scalar( keys %{$active} );
   $self->logt( "Instant Runoff Voting",
@@ -132,7 +136,7 @@ Instant Runoff Voting Looks for a Majority Winner. If one isn't present the choi
 
 Instant Runoff Voting is easy to count by hand and meets the Later Harm and Condorcet Loser Criteria. It, unfortunately, fails a large number of consistency criteria; the order of candidate dropping matters and small changes to the votes of non-winning choices that result in changes to the dropping order can change the outcome.
 
-Instant Runoff Voting is also known as Alternative Vote and as the Hare Method. 
+Instant Runoff Voting is also known as Alternative Vote and as the Hare Method.
 
 =head2 Tie Handling
 
